@@ -147,7 +147,8 @@ class BaseType(metaclass=TypeMeta):
         assert False
 
     @staticmethod
-    def format(value):
+    def format(value, choices=None):
+        assert not choices
         return value
 
     @staticmethod
@@ -184,6 +185,23 @@ class StringType(BaseType):
     }
 
 
+class ChoiceTypeMixin:
+    default_value = None
+
+    @staticmethod
+    def format(value, choices=None):
+        assert choices
+        return dict(choices)[value]
+
+
+class StringChoiceType(ChoiceTypeMixin, StringType):
+    lookups = {
+        **StringType.lookups,
+        "equals": "stringchoice",
+        "not_equals": "stringchoice",
+    }
+
+
 class RegexType(BaseType):
     default_value = ".*"
 
@@ -214,7 +232,8 @@ class NumberType(BaseType):
     }
 
     @staticmethod
-    def format(value):
+    def format(value, choices=None):
+        assert not choices
         return float(value) if value is not None else None
 
     @staticmethod
@@ -222,6 +241,14 @@ class NumberType(BaseType):
         return float(value)
 
 
+class NumberChoiceType(ChoiceTypeMixin, NumberType):
+    lookups = {
+        **NumberType.lookups,
+        "equals": "numberchoice",
+        "not_equals": "numberchoice",
+    }
+
+
 class YearType(NumberType):
     default_value = timezone.now().year
     lookups = {
@@ -261,7 +288,8 @@ class DateTimeType(BaseType):
         return timezone.make_aware(dateutil.parser.parse(value))
 
     @staticmethod
-    def format(value):
+    def format(value, choices=None):
+        assert not choices
         return str(timezone.make_naive(value)) if value else None
 
 
@@ -284,7 +312,8 @@ class DateType(BaseType):
         return timezone.make_aware(dateutil.parser.parse(value)).date()
 
     @staticmethod
-    def format(value):
+    def format(value, choices=None):
+        assert not choices
         return str(value) if value else None
 
 
@@ -303,7 +332,8 @@ class WeekDayType(BaseType):
     ]
 
     @classmethod
-    def format(cls, value):
+    def format(cls, value, choices=None):
+        assert not choices
         return cls._days[value - 1] if value else None
 
     @classmethod
@@ -334,7 +364,8 @@ class MonthType(BaseType):
     ]
 
     @classmethod
-    def format(cls, value):
+    def format(cls, value, choices=None):
+        assert not choices
         return cls._months[value - 1] if value else None
 
     @classmethod
