@@ -66,6 +66,8 @@ class ProductMixin:
         "onsale",
         "image",
         "created_time",
+        "number_choice",
+        "string_choice",
     ]
     readonly_fields = ["id", "is_onsale"]
 
